@@ -6,16 +6,22 @@ from bsrgan.models.network_rrdbnet import RRDBNet
 from bsrgan.main_download_pretrained_models import attempt_download_from_hub
 
 class BSRGAN:
-    def __init__(self, model_path, device):
+    def __init__(self, model_path, device, hf_model=False):
         self.device = device
-        self.model_path = attempt_download_from_hub(model_path, hf_token=None)
         self.save = True
+        
+        if hf_model:
+            model_path = attempt_download_from_hub(model_path)
+        else:
+            model_path = model_path
+        
+        self.model_path = model_path
+        
         self.load_model()
     
     def load_model(self):
-        
         model_name = os.path.splitext(os.path.basename(self.model_path))[0]
-        if [model_name] in ['BSRGANx2']:
+        if model_name == 'BSRGANx2':
             sf = 2
         else:
             sf = 4
@@ -49,5 +55,5 @@ class BSRGAN:
 if __name__ == '__main__':
     model_path = 'kadirnar/bsrgan'
     img_path = 'data/images/butterfly.png'
-    bsrgan = BSRGAN(model_path, device='cuda:0')
-    result = bsrgan.predict(img_path)
+    bsrgan = BSRGAN(model_path, device='cuda:0', hf_model=True)
+    result = bsrgan.predict(img_path)
\ No newline at end of file
